* 2012_panel_csv.do
* 
* STATA Command Syntax File
* Stata 15.1;
*
* The following do-file transforms the country separated EU-SILC CSV-data (as released by Eurostat) 
* into a combined CSV systemfile to be used before eusilcpanel by Marwin Borst(2018)
*
* Borst, Marwin (2018): EU-SILC Tools: eusilcpanel. 
* First computational steps towards a cumulative sample based on the EU-SILC longitudinal datasets.  
* GESIS Papers 2018/11                               
* Available on: https://www.gesis.org/gml/european-microdata/eu-silc/
* 
* EU-SILC - Panel 2012
*
* (c) GESIS 2018-06-26
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Valentina Ponomarenko
* https://www.gesis.org/gml/european-microdata/eu-silc/
*
* Contact: valentina.ponomarenko@gesis.org


/* Initialization commands */

clear 
capture log close
set more off
version 15.1
set linesize 250
set varabbrev off
#delimit ;

	
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ;
* CONFIGURATION SECTION - Start ;

* The following command should contain the complete path and
* name of the Stata log file.
* Change LOG_FILENAME to your filename ; 

local log_file "LOG_FILENAME" ;

* The following command should contain the complete path where the CSV data files are stored
* Change CSV_PATH to your file path (e.g.: C:/EU-SILC/Longitudinal 2005-2015) 
* Use forward slashes and keep path structure as delivered by Eurostat CSV_PATH/COUNTRY/YEAR ; 

global csv_path "CSV_PATH" ;

* The following commands should contain the complete path and name of the  four CSV files
* Change CSV_D_FILENAME to your final filename ;

local csv_d_file "CSV_D_FILENAME" ;

* Change CSV_H_FILENAME to your final filename ;

local csv_h_file "CSV_H_FILENAME" ;

* Change CSV_R_FILENAME to your final filename ;

local csv_r_file "CSV_R_FILENAME" ;

* Change CSV_P_FILENAME to your final filename ;

local csv_p_file "CSV_P_FILENAME" ;

* CONFIGURATION SECTION - End ;


* There should be probably nothing to change below this line ;
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ;

* Loop to open and convert D-files country files into one csv file ;

tempfile temp ;
save `temp', emptyok ;

foreach CC in AT BE BG CY CZ DK EE EL ES FI FR HR HU IE IS IT LT LU LV MT NL NO PL PT RO SE SI SK UK { ;
	cd "$csv_path/`CC'/2012" ;
	import delimited using "UDB_l`CC'12D.csv", case(preserve) clear ;
		* In NL, PT and SI DB040 is missing and read as numeric.
		* To prevent errors in the append command, it needs to be set to string ;
		tostring DB040, replace ;
append using `temp', force ;
save `temp', replace  ;
} ;
sort DB020 ;
export delimited "`csv_d_file'", replace ;

* Loop to open and convert H-files country files into one csv file ;

clear ;
tempfile temp ;
save `temp', emptyok ;

foreach CC in AT BE BG CY CZ DK EE EL ES FI FR HR HU IE IS IT LT LU LV MT NL NO PL PT RO SE SI SK UK { ;
	cd "$csv_path/`CC'/2012" ;
	import delimited using "UDB_l`CC'12H.csv", case(preserve) clear ;
append using `temp', force ;
save `temp', replace  ;
} ;
sort HB020 ;
export delimited "`csv_h_file'", replace ;

* Loop to open and convert R-files country files into one csv file ;

clear ;
tempfile temp ;
save `temp', emptyok ;

foreach CC in AT BE BG CY CZ DK EE EL ES FI FR HR HU IE IS IT LT LU LV MT NL NO PL PT RO SE SI SK UK { ;
	cd "$csv_path/`CC'/2012" ;
	import delimited using "UDB_l`CC'12R.csv", case(preserve) clear ;
append using `temp', force ;
save `temp', replace  ;
} ;
sort RB020 ;
export delimited "`csv_r_file'", replace ;

* Loop to open and convert P-files country files into one csv file ;

clear ;
tempfile temp ;
save `temp', emptyok ;

foreach CC in AT BE BG CY CZ DK EE EL ES FI FR HR HU IE IS IT LT LU LV MT NL NO PL PT RO SE SI SK UK { ;
	cd "$csv_path/`CC'/2012" ;
	import delimited using "UDB_l`CC'12P.csv", case(preserve) clear ;
append using `temp', force ;
save `temp', replace  ;
} ;
sort PB020 ;
export delimited "`csv_p_file'", replace ;


log close ;
set more on
#delimit cr 
	
